#!/bin/bash
 
# dtnmailex-listenack.sh
#
# Written for N4C Summer Trials
# Eoin Meehan May 2009
#r
# This script runs constantly listening for incoming delivery acks from the DTN
# Outgoing mail is sent in one bundle and when it reaches the far end of the DTN (the internet
# mail gateway) the far end sends back a delivery ack

# First check if I'm running already - if so exit and do nothing

SERVICE="dtnmailex-listenack"
PID=$$
LOCKFILE='/etc/dtnmailex/dtnmailex-listenack.lock'

if [ -f $LOCKFILE ]; then
	lockfilepid=`cat $LOCKFILE`
	ps -fp $lockfilepid > /dev/null && exit	# is this pid already running? If so exit ...
fi

# If we're here we were not running.	
# Remember out PID to the lockfile

echo $$ > $LOCKFILE

echo "dtnmailex-listenack.sh started"

MAIL_DIR=/var/spool/dtnmailex/todtn
DELIVERY_DIR=/var/spool/dtnmailex/todtn/delivery
 
# Exit codes from <sysexits.h>
EX_TEMPFAIL=75
EX_UNAVAILABLE=69


# Clean up when done or when aborting.
#trap "rm -f out.$$" 0 1 2 3 15
 
# Start processing.


cd $DELIVERY_DIR || {
     echo $DELIVERY_DIR does not exist; exit $EX_TEMPFAIL; }

# Fire up dtnrecv to listen for incoming acks. Process 1 at a time to prevent loss
# The line with the bundle ID should be the only one with a fullstop eg 999999.99
# -s returns bundle ID withing the ack packet 
# -N is dont try to use existing registration

while [ 1 ]; do				# ie forever

	bundleid=`dtnrecv -q -s -n 1 -N dtn://pixel2.dtn/mailfromvillage | grep '\.'`

	echo "------------- Begin Ack Processing -------------"
	date

	echo "Bundle ID = "$bundleid ${#bundleid} 
 
	if [ -z "$bundleid" ] ; then
		echo "listenack - Error invoking dtnrecv"; exit $EX_TEMPFAIL;
	fi

	echo "Received "$bundleid" ... looking in "$DELIVERY_DIR

		if [ -e "$bundleid" ] ; then
		    mailfile=`cat $bundleid`
		    echo "Bundleid = "$bundleid" Mailfile = "$mailfile
		    echo "Removing "$bundleid" and "$mailfile
		    rm $MAIL_DIR/$mailfile || echo "No mail file found" $mailfile
		    rm $DELIVERY_DIR/$bundleid || echo "No Delivery file found "$bundleid
		else
		    echo "Warning - ack received for non-existant email "$bundleid
		fi
	echo "------------- End Ack Processing ----------"

done

exit $?



