#!/bin/bash
 
# dtnmailex-sweeper.sh
#
# Written for N4C Summer Trials
# Eoin Meehan May 2009
#
# This script runs every day via cron and reads the delivery ack directory.
# If any ack files are older than 5 days it deletes them and the corresponding mail file and
# returns a notice to the sender indicating that the file may not have been delivered.

# Localize these. The -G option does nothing before Postfix 2.3.
MAIL_DIR=/var/spool/dtnmailex/todtn
DELIVERY_DIR=/var/spool/dtnmailex/todtn/delivery
SENDMAIL="/usr/sbin/sendmail -G -i" # NEVER NEVER NEVER use "-t" here.
NONDELIVERYNOTICE="/etc/dtnmailex/nondeliverynotice.txt"
POSTMASTERNAME="Village Postmaster"
POSTMASTERADD="postmaster@village.n4c.eu"
 
# Exit codes from <sysexits.h>
EX_TEMPFAIL=75
EX_UNAVAILABLE=69

# Clean up when done or when aborting.
#trap "rm -f out.$$" 0 1 2 3 15
 
# Start processing.


cd $DELIVERY_DIR || {
     echo $DELIVERY_DIR does not exist; exit $EX_TEMPFAIL; }


for bundleid in `find . -mtime +4 -prin`		# Find all files with mod dates older
							# than 5 days (5 x 25 hour periods)

	echo "Looking in "$DELIVERY_DIR" for file "$bundleid

		if [ -e "$bundleid" ] ; then
		    mailfile=`cat $bundleid`

			sender = `cat $mailfile | grep "From:" | sed 's/From://'`
			cat $NONDELIVERYNOTICE $mailfile | sendmail  -f $POSTMASTERADD -F $POSTMASTERNAME $sender || echo "Sweeper: Error sending pNDN" $mailfile

		    echo "Bundleid = "$bundleid" Mailfile = "$mailfile
		    echo "Removing "$bundleid" and "$mailfile
		    rm $MAIL_DIR/$mailfile || echo "No mail file found" $mailfile
		    rm $DELIVERY_DIR/$bundleid || echo "No Delivery file found "$bundleid
		else
		    echo "Error finding "$bundleid
		fi

done

exit $?



