#!/bin/sh
 
# dtnmailex-todtn.sh
#
# Written for N4C Summer Trials
# Eoin Meehan May 2009
#
#
# Invoked by Postfix via pipe channel to send mail to the DTN

# Localize these. The -G option does nothing before Postfix 2.3.
INSPECT_DIR=/var/spool/dtnmailex/todtn
DELIVERY_DIR=/var/spool/dtnmailex/todtn/delivery
SENDMAIL="/usr/sbin/sendmail -G -i" # NEVER NEVER NEVER use "-t" here.
 
# Exit codes from <sysexits.h>
EX_TEMPFAIL=75
EX_UNAVAILABLE=69

# Clean up when done or when aborting.
#trap "rm -f out.$$" 0 1 2 3 15
 
# Start processing.
cd $INSPECT_DIR || {
     echo $INSPECT_DIR does not exist; exit $EX_TEMPFAIL; }

cat >out.$$ || { 
     echo Cannot save mail to file; exit $EX_TEMPFAIL; }

# Specify your content filter here.

# filter <in.$$ || {
#   echo Message content rejected; exit $EX_UNAVAILABLE; }


#$SENDMAIL "$@" <in.$$

# ETM
# Rename the temporary file to a file named as the message id
# Search the file for "message id" header; erase up to the < and from the @
# then there might be multiple message id headers (if forwarding for example) so delete from
# line 2 to the end
# Attempt to send the file named "_NOT_SENT"
# If the dtnsend works then rename the file to "_SENT"
# This way the sweeper cron job can see whats gone and whats not.
#

tmpname=`cat out.$$ | grep 'Message-Id' | sed 's/Message-Id: <//1' | sed 's/\@.*//g' | sed '2,$d'`
sentname=$tmpname'_SENT'
notsentname=$tmpname'_WAITING'

echo 'tmpname = ' $tmpname

mv out.$$ $notsentname

# Send the file to the DTN requesting a delivery ack (-D)
# pipe the output to grab the bundle id from the packet

chmod 644 $notsentname

bundleid=`dtnsend -d dtn://pixel2.dtn/mailtogw -s dtn://pixel2.dtn/mailfromvillage -p $notsentname -t f -v -D | grep 'bundle sent successfully:' | sed 's/^.*,//'` 

# We will always end up here even if the dtnsend fails - so check the value of bundleid
# If its 0 length then the dtnsend had a problem so dont rename the file and exit

if [ -z $bundleid]; then
	echo 'Error invoking dtnsend with file' $notsentname; exit $EX_TEMPFAIL;
fi
	
echo 'bundle id = ' $bundleid 
mv $notsentname $sentname

# Create a file in the delivery directory named the bundle id, and write into it the mailid
# When a delivery ack comes in from the DTN it will specify the bundle id, open the corresponding 
# file and find the mail id it matches.

echo $DELIVERY_DIR/$bundleid

echo $sentname > $DELIVERY_DIR/$bundleid || {
     echo Error writing to $DELIVERY_DIR; exit $EX_TEMPFAIL; }

exit $?



