#!/bin/sh
 
# dtnmailex-todtn-sweeper.sh
#
# Written for N4C Summer Trials
# Eoin Meehan May 2009
#
#
# Invoked by cron to check for mail that failed due to the DTN daemon not being available
# May also do other stuff later

# Localize these. The -G option does nothing before Postfix 2.3.
INSPECT_DIR=/var/spool/dtnmailex/todtn
DELIVERY_DIR=/var/spool/dtnmailex/todtn/delivery
SENDMAIL="/usr/sbin/sendmail -G -i" # NEVER NEVER NEVER use "-t" here.
 
# Exit codes from <sysexits.h>
EX_TEMPFAIL=75
EX_UNAVAILABLE=69

# Clean up when done or when aborting.
#trap "rm -f out.$$" 0 1 2 3 15
 
# Start processing.

cd $INSPECT_DIR || {
     echo $INSPECT_DIR does not exist; exit $EX_TEMPFAIL; }

# List out all files with WAITING in the name and resent

for notsentname in `ls *WAITING*`
do
  echo "Processing $notsentname file..."

	bundleid=`dtnsend -d dtn://pixel2.dtn/mailtogw -s dtn://pixel2.dtn/mailfromvillage -p $notsentname -t f -v -D | grep 'bundle sent successfully:' | sed 's/^.*,//'` 

	# We will always end up here even if the dtnsend fails - so check the value of bundleid
	# If its 0 length then the dtnsend had a problem so dont rename the file and exit

	if [ -z $bundleid]; then
		echo 'Sweeper - Error invoking dtnsend with file' $notsentname; exit $EX_TEMPFAIL;
	fi
	
	echo 'bundle id = ' $bundleid 
	sentname=`echo $notsentname | sed 's/_WAITING/_SENT/'`

	mv $notsentname $sentname

	# Create a file in the delivery directory named the bundle id, and write into it the mailid
	# When a delivery ack comes in from the DTN it will specify the bundle id, open the
	# corresponding file and find the mail id it matches.

	echo $DELIVERY_DIR/$bundleid

	echo $sentname > $DELIVERY_DIR/$bundleid || {
     		echo Error writing to $DELIVERY_DIR; exit $EX_TEMPFAIL; }

done


exit $?



